@@ -38,7 +38,8 @@
 #include <hildon/hildon-file-chooser-dialog.h>
 #else
 #include <hildon-widgets/hildon-app.h>
-#include <hildon-fm/hildon-widgets/hildon-file-chooser-dialog.h>
+/*#include <hildon-fm/hildon-widgets/hildon-file-chooser-dialog.h>*/
+#include <hildon-fm-2/hildon/hildon-file-chooser-dialog.h> 
 #include <hildon-widgets/hildon-note.h>
 #include <hildon-widgets/hildon-font-selection-dialog.h>
 #include <hildon-widgets/hildon-get-password-dialog.h>
@@ -53,7 +54,7 @@ static void create_toolbar( MainView *main );
 void create_textarea( MainView *main );
 GtkWidget *show_rec_line(GtkWidget *sizer, char *label, char *txt, int row, int col);
 
-inline const char *emptynull(const char *a) { return (a==NULL) ? "" : a;}
+inline char *emptynull(char *a) { return (a==NULL) ? "" : a;}
 
 /* Creates and initialises a main_view */
 MainView* interface_main_view_new( AppData *data ) {
@@ -151,8 +152,8 @@ void show_rec(MainView *main, rec *r) {
 	rec_win->delete_button = gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), GTK_STOCK_DELETE, 4);
 	rec_win->edit_button = gtk_dialog_add_button(GTK_DIALOG(rec_win->dialog), "Edit", 5);
 /*	gtk_button_set_image(GTK_BUTTON(rec_win->edit_button), GTK_STOCK_EDIT); */
-	g_object_set(rec_win->dialog, "content_area_border", 1, "button_spacing", 20, NULL);
-/*  where's , "action_area_border" ? */
+    g_object_set(rec_win->dialog, "content-area-border", 1, "button_spacing", 20, NULL);
+    /*  where's "button-spacing", "content-area-border", "action_area_border" ? - not in scratchbox, maybe on n800 */
 	g_signal_connect(rec_win->dialog, "response", G_CALLBACK ( callback_rec_response), main);
 	sizer=gtk_table_new(5, 4, TRUE);
 	rec_win->title=show_rec_line(sizer, "Title", r->title, 0, 0);
@@ -210,16 +211,18 @@ void populate_iconView (MainView *main, char *group) {
 	}
 	while (onrec!=NULL) {
 		rec *data=(rec *) onrec->data;
-		if (strcmp(emptynull(data->group), group)==0) {
-			addItemToIconView(main, emptynull(data->title), GTK_STOCK_FILE, data);
-		} else {
-			if (group[0]=='\0') { /* show all groups at top level */
-				if (strcmp(lastgroup, emptynull(data->group))!=0) { /* supress duplicate group folders */
-					addItemToIconView(main, data->group, GTK_STOCK_DIRECTORY, data);
-					lastgroup=data->group;
-				}
-			}
-		}
+        if (data->skip == 0) {
+            if (strcmp(emptynull(data->group), group)==0) {
+                addItemToIconView(main, emptynull(data->title), GTK_STOCK_FILE, data);
+            } else {
+                if (group[0]=='\0') { /* show all groups at top level */
+                    if (strcmp(lastgroup, emptynull(data->group))!=0) { /* supress duplicate group folders */
+                        addItemToIconView(main, data->group, GTK_STOCK_DIRECTORY, data);
+                        lastgroup=data->group;
+                    }
+                }
+            }
+        }
 		onrec=g_list_next(onrec);
 	}
 	interface_show_state(main);
@@ -299,7 +302,7 @@ static void create_menu( MainView *main )
 	GtkMenu *main_menu;
 	GtkWidget *file_menu, *view_menu;
 	GtkWidget *separator = NULL;
-	GtkWidget *close = NULL;
+	GtkWidget *quit = NULL;
 
 	/* Get the menu of our view */
 	main_menu = GTK_MENU( gtk_menu_new () );
@@ -317,6 +320,7 @@ static void create_menu( MainView *main )
 	main->close_item = gtk_menu_item_new_with_label ( _("Close") );
 	main->save_item = gtk_menu_item_new_with_label ( _("Save") );
 	main->saveas_item = gtk_menu_item_new_with_label ( _("Save As...") );
+    main->export_item = gtk_menu_item_new_with_label ( _("Export...") );
 	
 	main->view_item = gtk_menu_item_new_with_label ( _("View") );
 	main->large_icons_item = gtk_menu_item_new_with_label ( _("Large Icons") );
@@ -326,7 +330,7 @@ static void create_menu( MainView *main )
 	main->add_item = gtk_menu_item_new_with_label ( _("Add Entry") );
 	main->change_password = gtk_menu_item_new_with_label ( _("Change Password") );
 	separator = gtk_separator_menu_item_new();
-	close = gtk_menu_item_new_with_label( _("Close") );
+	quit = gtk_menu_item_new_with_label( _("Quit") );
 
 	/* Add menu items to right menus */
 	gtk_menu_append( main_menu, main->file_item );
@@ -336,6 +340,7 @@ static void create_menu( MainView *main )
 	gtk_menu_append( file_menu, main->close_item );
 	gtk_menu_append( file_menu, main->save_item );
 	gtk_menu_append( file_menu, main->saveas_item );
+    gtk_menu_append( file_menu, main->export_item );
  
 	gtk_menu_append( main_menu, main->view_item );
 	gtk_menu_append( view_menu, main->large_icons_item );
@@ -345,7 +350,7 @@ static void create_menu( MainView *main )
 	gtk_menu_append( main_menu, main->change_password );
 	gtk_menu_append( main_menu, main->fullscreen_item );
 	gtk_menu_append( main_menu, separator );
-	gtk_menu_append( main_menu, close );
+	gtk_menu_append( main_menu, quit );
 
 	/* Add submenus to the right items */
 	gtk_menu_item_set_submenu( GTK_MENU_ITEM (main->file_item), file_menu );
@@ -358,12 +363,13 @@ static void create_menu( MainView *main )
 	g_signal_connect( G_OBJECT( main->close_item ), "activate",  G_CALLBACK ( callback_file_close), main );
 	g_signal_connect( G_OBJECT( main->save_item ), "activate",  G_CALLBACK ( callback_file_save), main );
 	g_signal_connect( G_OBJECT( main->saveas_item ), "activate",  G_CALLBACK ( callback_file_saveas), main );
+    g_signal_connect( G_OBJECT( main->export_item ), "activate",  G_CALLBACK ( callback_export), main );
 	g_signal_connect( G_OBJECT( main->large_icons_item ), "activate",  G_CALLBACK ( callback_large_icons), main );
 	g_signal_connect( G_OBJECT( main->small_icons_item ), "activate",  G_CALLBACK ( callback_small_icons), main );
 	g_signal_connect( G_OBJECT( main->add_item ), "activate",  G_CALLBACK ( callback_add_entry), main );
 	g_signal_connect( G_OBJECT( main->change_password ), "activate",  G_CALLBACK ( callback_change_password), main );
 	g_signal_connect( G_OBJECT( main->fullscreen_item ), "activate",  G_CALLBACK ( callback_fullscreen ), main );
-	g_signal_connect( G_OBJECT( close ), "activate", gtk_main_quit, NULL );
+	g_signal_connect( G_OBJECT( quit ), "activate", gtk_main_quit, NULL );
 
 	/* We need to show menu items */
 	gtk_widget_show_all( GTK_WIDGET( main_menu ) );
@@ -372,14 +378,17 @@ static void create_menu( MainView *main )
 void interface_show_state(MainView *main) {
 	gboolean fopen;
 	fopen=(main->pass!=NULL);
-	gtk_widget_set_sensitive(main->new_item, !fopen);
-	gtk_widget_set_sensitive(main->open_item, !fopen);
-	gtk_widget_set_sensitive(main->open_last_item, main->last_file && (!fopen));
-	gtk_widget_set_sensitive(main->close_item, fopen);
-	gtk_widget_set_sensitive(main->save_item, fopen);
-	gtk_widget_set_sensitive(main->saveas_item, fopen);
-	gtk_widget_set_sensitive(main->change_password, fopen);
-	gtk_widget_set_sensitive(main->add_item, fopen);
+    if (GTK_IS_WIDGET(main->new_item)) {    /* ignore menu if it's not there (eg. during app close) */
+    	gtk_widget_set_sensitive(main->new_item, !fopen);
+	    gtk_widget_set_sensitive(main->open_item, !fopen);
+    	gtk_widget_set_sensitive(main->open_last_item, main->last_file && (!fopen));
+    	gtk_widget_set_sensitive(main->close_item, fopen);
+    	gtk_widget_set_sensitive(main->save_item, fopen);
+    	gtk_widget_set_sensitive(main->saveas_item, fopen);
+        gtk_widget_set_sensitive(main->export_item, fopen);
+    	gtk_widget_set_sensitive(main->change_password, fopen);
+    	gtk_widget_set_sensitive(main->add_item, fopen);
+    }
 	
 	if (GTK_IS_WIDGET(main->new_tb)) {	/* ignore toolbar if it's not there (eg. during app close) */
 		gtk_widget_set_sensitive(GTK_WIDGET(main->new_tb), !fopen);
@@ -389,6 +398,7 @@ void interface_show_state(MainView *main) {
 		gtk_widget_set_sensitive(GTK_WIDGET(main->saveas_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->change_password_tb), fopen);
 		gtk_widget_set_sensitive(GTK_WIDGET(main->add_tb), fopen);
+        gtk_widget_set_sensitive(GTK_WIDGET(main->filter_tb), fopen);
 	}
 }
 
@@ -429,8 +439,16 @@ static void create_toolbar ( MainView *main ) {
 	main->change_password_tb = gtk_tool_button_new_from_stock(GTK_STOCK_CONVERT);
 	main->separator_tb2 = gtk_separator_tool_item_new();
 	main->fullscreen_tb = gtk_tool_button_new_from_stock( GTK_STOCK_ZOOM_FIT );
-
-	/* Insert items to toolbar */
+    main->separator_tb3 = gtk_separator_tool_item_new();
+    
+    /* create filter text entry in a container */
+    main->filter_item_tb = gtk_tool_item_new();
+    gtk_tool_item_set_expand(main->filter_item_tb, TRUE); 
+    main->filter_tb = gtk_entry_new();
+    /* gtk_entry_set_max_length( GTK_ENTRY(main->filter_tb) , (gint) 24);  */
+    gtk_container_add( GTK_CONTAINER( main->filter_item_tb ) , main->filter_tb);
+	
+    /* Insert items to toolbar */
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->new_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->open_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->close_tb, -1);
@@ -441,6 +459,8 @@ static void create_toolbar ( MainView *main ) {
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->change_password_tb, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb2, -1);
 	gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->fullscreen_tb, -1);
+    gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->separator_tb3, -1);
+    gtk_toolbar_insert ( GTK_TOOLBAR(main->toolbar), main->filter_item_tb, -1);
 
 	/* Connect signals to buttons */
 	g_signal_connect(G_OBJECT(main->new_tb), "clicked", G_CALLBACK(callback_file_new), main);
@@ -451,6 +471,7 @@ static void create_toolbar ( MainView *main ) {
 	g_signal_connect(G_OBJECT(main->add_tb), "clicked", G_CALLBACK(callback_add_entry), main);
 	g_signal_connect(G_OBJECT(main->change_password_tb), "clicked", G_CALLBACK(callback_change_password), main);
 	g_signal_connect(G_OBJECT(main->fullscreen_tb), "clicked", G_CALLBACK(callback_fullscreen), main);
+    g_signal_connect(G_OBJECT(main->filter_tb), "activate", G_CALLBACK(callback_filter), main);
 	
 	/* Attach toolbar to main view */
 	hildon_window_add_toolbar(main->data->main_view, GTK_TOOLBAR(main->toolbar)); 
